@@ -32,7 +32,7 @@ class Attention(nn.Module):
         combined = torch.cat((mix, output), dim=2)
 
         # output -> (batch, out_len, dim)
-        output = F.tanh(self.linear_out(combined.view(-1, 2 * hidden_size))).view(batch_size, -1, hidden_size)
+        output = torch.tanh(self.linear_out(combined.view(-1, 2 * hidden_size))).view(batch_size, -1, hidden_size)
 
         if not output.is_contiguous():
             output = output.contiguous()
